# Archive Date Footer plugin for Movable Type
#
# Release 1.00 (Jun 17, 2006)
#         1.01 (Jan 20, 2006) add sort_order attribute.
#         1.02 (Mar 19, 2007) fix bug for weekly archives.
#         2.00 (Jul 08, 2007) for MT4.
#
# This software is provided as-is. You may use it for commercial or
# personal use. If you distribute it, please keep this notice intact.
#
# Copyright (c) 2006-2007 Yujiro Araki

package MT::Plugin::ArchiveDateFooter;
use strict;
use base qw(MT::Plugin);
use vars qw($VERSION);

use MT::Template::Context;
use MT::Util qw(get_entry);

MT::Template::Context->add_container_tag(ArchiveDateFooter => \&_hdlr_archive_date_footer);

BEGIN {
    $VERSION = '2.00';
    my $plugin = MT::Plugin::ArchiveDateFooter->new ({
        name => 'ArchiveDateFooter Plugin',
        description => 'MTArchiveDateFooter tag.',
        doc_link => 'http://www.koikikukan.com/archives/2006/06/19-010000.php',
        version => $VERSION,
        });
    MT->add_plugin ($plugin);
}

sub _hdlr_archive_date_footer {
    my($ctx, $args) = @_;
    my $at = $ctx->{current_archive_type}
        or return $ctx->error(MT->translate(
           "You used an [_1] tag outside of the proper context.", "<MTArchiveDateFooter>" ));
    my $arctype = MT->publisher->archiver($at);
    my $ts = $args->{ts} || $_[0]->{current_timestamp};
    my @arg = ($ts, $ctx->stash('blog_id'), $at);
    my $is_prev = ($args->{sort_order} || '') eq 'ascend' ? 0 : 1;
    push @arg, $is_prev ? 'previous' : 'next';
    my $helper = $arctype->date_range;
    my ($start, $end);
    if (my $entry = get_entry(@arg)) {
        my $builder = $ctx->stash('builder');
        local $ctx->{__stash}->{entries} = [ $entry ];
        ($start, $end) = $helper->($entry->authored_on);
    }
    my $current_date;
    if ($at eq "Monthly") {
        $current_date = substr $ts, 0, 4;
        $start = substr $start, 0, 4;
    } elsif ($at eq "Weekly"){
        $current_date = substr $ts, 4, 2;
        $start = substr $start, 4, 2;
    } else {
        return '';
    }
    if ($start != $current_date) {
        my $builder = $ctx->stash('builder');
        my $tokens = $ctx->stash('tokens');
        defined(my $out = $builder->build($ctx,$tokens))
            or return '';
        return $out;
    }
}
